@@ -1,5 +1,4 @@
-from dataclasses import dataclass
-from datetime import datetime
+from dataclasses import dataclass, asdict
 import ast
 import inspect
 import requests, json
@@ -25,11 +24,14 @@ class MintTransaction:
             for k, v in env.items() if k in inspect.signature(cls).parameters
         })
 
+    def asDict(self):
+        return asdict(self)
+
     def asYNAB(self):
         return YNABTransaction(
             **{
                 "date": self.date,
-                "amount": int(self.amount) * 1000,
+                "amount": int(self.amount * 1000),
                 "account_id": stash.ynab_account_id,
                 "payee_name": self.inferredDescription,
                 "import_id": self.id,
@@ -44,8 +46,22 @@ class YNABTransaction:
     account_id: str
     payee_name: str
     import_id: str
+    id: str = None
+    payee_id: str = None
+    category_id: str = None
+    memo: str = None
+    cleared: str = None
+    approved: str = None
+    flag_color: str = None
+    subtransactions: list = None
     cleared: str = 'cleared'
 
+    def __post_init__(self):
+        self.payee_name = self.payee_name[:100]
+
+    def asDict(self):
+        return asdict(self)
+
     @classmethod
     def from_dict(cls, env):
         return cls(**{
@@ -62,37 +78,29 @@ class MintAPI():
         self.cpath = arg('mint_cookies')
         self.keypath = arg('mint_api_key_file')
 
-    def freshMints(self):
-        client = self.restClient()
-
-        client.authorize(self.cookies(), self.key())
+    def getXtns(self):
         try:
-            items = client.get_transaction_data()
-        except:
-            self.updateAuth()
+            client = self.restClient()
             client.authorize(self.cookies(), self.key())
             items = client.get_transaction_data()
-        finally:
-            return recent(
-                [MintTransaction.from_dict(item['fiData']) for item in items])
+            return [
+                MintTransaction.from_dict(item['fiData']) for item in items
+            ]
+        except IsADirectoryError as e:
+            print(e)
+            print("""
+                  One or more expected files is a directory instead \n
+                  If you don't have a value to supply, simply create \n
+                  an empty file in the desired location \n
+                  """)
 
     def cookies(self):
-        try:
-            with open(self.cpath, 'r') as file:
-                return ast.literal_eval(file.read())
-        except FileNotFoundError:
-            self.updateAuth()
-            with open(self.cpath, 'r') as file:
-                return ast.literal_eval(file.read())
+        with open(self.cpath, 'r') as file:
+            return ast.literal_eval(file.read())
 
     def key(self):
-        try:
-            with open(self.keypath, 'r') as file:
-                return ast.literal_eval(file.read())['authorization']
-        except FileNotFoundError:
-            self.updateAuth()
-            with open(self.keypath, 'r') as file:
-                return ast.literal_eval(file.read())['authorization']
+        with open(self.keypath, 'r') as file:
+            return ast.literal_eval(file.read())['authorization']
 
     def updateAuth(self):
         bowser = self.browser(
@@ -121,13 +129,29 @@ class YNABAPI():
             "Authorization": f"Bearer {stash.ynab_api_key}"
         }
 
+    def _patch(self, url, **kwargs):
+        return requests.patch(self.uri + url, **kwargs, headers=self.headers)
+
     def _post(self, url, **kwargs):
         return requests.post(self.uri + url, **kwargs, headers=self.headers)
 
     def _get(self, url, **kwargs):
         return requests.get(self.uri + url, **kwargs, headers=self.headers)
 
-    def bulkPostTransactions(self, transactions: dict):
+    def bulkPatchTransactions(self, transactions: list):
+        url = f'/budgets/{stash.ynab_budget_id}/transactions'
+        # this json doesn't seem to like being too long. it works
+        # with 10 items, and breaks with 250, but I'm not sure where
+        # they meet
+        json = {"transactions": transactions}
+        results = self._patch(
+            url,
+            json=json,
+        )
+
+        return real(results)
+
+    def bulkPostTransactions(self, transactions: list):
         results = self._post(
             f'/budgets/{stash.ynab_budget_id}/transactions',
             json={"transactions": transactions},
@@ -135,11 +159,11 @@ class YNABAPI():
 
         return real(results)
 
-    def getTransactions(self, since_date: str = '', type: str = ''):
+    def getUglyTransactions(self, since_date: str = '', type: str = ''):
         """
-        Return all recent transactions
+        Return transactions as raw json
         """
-        result = self._get(
+        return self._get(
             f'/budgets/{stash.ynab_budget_id}/transactions',
             json={"data": {
                 "since_date": since_date,
@@ -147,10 +171,21 @@ class YNABAPI():
             }},
         )
 
-        return recent([
+    def getXtns(self, since_date: str = '', type: str = ''):
+        """
+        Return transactions as YNABTransaction dataclass objects
+        """
+        result = self.getUglyTransactions(since_date, type)
+        return [
             YNABTransaction.from_dict(xt)
             for xt in real(result)['transactions']
-        ])
+        ]
+
+    def printXtns(self, since_date: str = '', type: str = ''):
+        result = self.getUglyTransactions(since_date, type)
+        print(
+            json.dumps(([xt for xt in real(result)['transactions']]),
+                       indent=2))
 
     def getAccounts(self):
         """
@@ -166,18 +201,9 @@ class YNABAPI():
         return real(self._get(url='/budgets'))['budgets']
 
 
-def recent(transactions) -> dict:
-    filter = lambda xtDate: xtDate >= str(arg('days'))
-    return [
-        xt for xt in transactions
-        if filter(datetime.strptime(xt.date, tfmt).strftime(tfmt))
-    ]
-
-
 def real(httpResponse) -> dict:
     answer = json.loads(httpResponse.content.decode('utf-8'))
     try:
         return answer['data']
-    except Exception as e:
-        print(answer)
-        raise e
+    except KeyError:
+        print(answer['error'])
