@@ -1,4 +1,3 @@
-from dataclasses import asdict
 import signal
 import sys
 
@@ -18,11 +17,9 @@ def main():
     ynapi = YNABAPI()
     mapi = MintAPI()
 
-    ydeez = [y.import_id for y in ynapi.getTransactions()]
-    nabs = [
-        asdict(mint.asYNAB()) for mint in mapi.freshMints()
-        if mint.id not in ydeez
-    ]
+    ydeez = [y.import_id for y in ynapi.getXtns()]
+    nabs = [mint.asYNAB() for mint in mapi.getXtns() if mint.id not in ydeez]
+    nabs = [nab.asDict() for nab in nabs]
     if arg('verbose'):
         print(nabs)
     if not arg('dryrun') and len(nabs) > 0:
@@ -31,7 +28,7 @@ def main():
 
 def handleArgs():
     if arg('print_ynab_transactions'):
-        sys.exit(YNABAPI().printTransactions())
+        sys.exit(YNABAPI().printXtns())
     if arg('quickstart'):
         from .quickstart import run
         sys.exit(run())
